from enum import Enum


class Activity(Enum):
    custom = 0  # you can insert activity_id parameter while setting this as activities, honestly very useless since nextcord already have target_application_id, but heck yeah
    poker = 1  # boost-locked
    betrayal = 2
    fishington = 3
    chess = 4  # boost-locked
    checker = 5  # boost-locked
    ocho = 6  # boost-locked
    youtube = 7
    doodle = 8
    letter_tile = 9  # boost-locked, now named letter_league
    word_snacks = 10
    sketch = 11
    spellcast = 12  # boost-locked
    letter_league = 13  # boost-locked
    awkword = 14  # boost-locked
    blazing = 15